@@ -1,5 +1,6 @@
 
 from django import template
+from django.forms.utils import flatatt
 from django.template.base import token_kwargs
 from django.template.loader import get_template
 from django.template.loader_tags import BlockNode, ExtendsNode, BlockContext
@@ -39,8 +40,6 @@ class ContextDict(dict):
     '''Back-port of the ContextDict from Django 1.7'''
     def __init__(self, context, *args, **kwargs):
         super(ContextDict, self).__init__(*args, **kwargs)
-
-        context.dicts.append(self)
         self.context = context
 
     def __enter__(self):
@@ -127,9 +126,8 @@ def field(context, field, widget=None, **kwargs):
         'form_field': field,
         'id': field.auto_id,
     }
-    for attr in ('css_classes', 'errors', 'field', 'form',
-            'help_text', 'id_for_label', 'label', 'name', 'html_name',
-            'value',):
+    for attr in ('css_classes', 'errors', 'field', 'form', 'help_text',
+                'html_name', 'id_for_label', 'label', 'name', 'value',):
         field_data[attr] = getattr(field, attr)
     for attr in ('choices', 'widget', 'required'):
         field_data[attr] = getattr(field.field, attr, None)
@@ -147,3 +145,6 @@ def use(context, widget, **kwargs):
     with ContextDict(context, kwargs) as context:
         return block.render(context)
 
+@register.filter
+def flat_attrs(attrs):
+    return flatatt(attrs)
